# History

All notable changes to this project will be documented in this file. This project adheres to [Semantic Versioning](http://semver.org/).

## 0.1.1 (2025-10-06)

- First release

## 0.1.1 (2025-11-05)

- Added `.js` and `.ps1` extensions that simply use `PlainTextUpdater` and do not try to validate/format on save.
